@@ -1,8 +1,5 @@
 package Getopt::Modular;
-{
-  $Getopt::Modular::VERSION = '0.12';
-}
-
+$Getopt::Modular::VERSION = '0.13';
 #ABSTRACT: Modular access to Getopt::Long
 
 use warnings;
@@ -612,7 +609,13 @@ sub getHelp
         no warnings 'uninitialized';
 
         $txt .= "\n " . ($cbs->{current_value} || sub { "Current value: [". shift(). "]" })->($param->{default}) if exists $param->{default};
-        $txt .= "\n " . ($cbs->{valid_values} || sub { "Valid values: [". join(',', @_). "]" })->(@{$param->{valid_values}}) if $param->{valid_values};
+
+        if ($param->{valid_values})
+        {
+            # if it's a code ref, de-ref it.  If not, ignore the exception.
+            eval { $param->{valid_values} = [ $param->{valid_values}->() ] };
+            $txt .= "\n " . ($cbs->{valid_values} || sub { "Valid values: [". join(',', @_). "]" })->(@{$param->{valid_values}});
+        }
 
         $tb->add($opt, $txt);
     }
@@ -700,13 +703,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Getopt::Modular - Modular access to Getopt::Long
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
